@@ -29,10 +29,10 @@ class TestIncrementListCounter:
 
     def test_function(self) -> None:
         """Increments counter at ilvl, deletes deeper counters."""
-        ilvl2count = {str(x): x for x in range(1, 6)}
-        assert ilvl2count == {"1": 1, "2": 2, "3": 3, "4": 4, "5": 5}
+        ilvl2count = {str(x): x for x in range(6)}
+        assert ilvl2count == {"0": 0, "1": 1, "2": 2, "3": 3, "4": 4, "5": 5}
         _increment_list_counter(ilvl2count, "2")
-        assert ilvl2count == {"1": 1, "2": 3}
+        assert ilvl2count == {"0": 1, "1": 1, "2": 3}
 
 
 @pytest.fixture()
